@@ -5,20 +5,41 @@ import re
 import time
 import argparse
 import subprocess
+from beartype import beartype
 from datetime import datetime
 from pathlib import Path
 from itertools import zip_longest
 from watchlogs.watchlogs import Watcher
-from typeguard import typechecked
+from typing import Optional
 
 
 class Yaspi:
 
-    def __init__(self, job_name, cmd, prep, recipe, gen_script_dir, log_dir,
-                 partition, job_array_size, cpus_per_task, gpus_per_task, refresh_logs,
-                 exclude, use_custom_ray_tmp_dir, ssh_forward, time_limit, throttle_array,
-                 mem, constraint_str, template_dir=Path(__file__).parent / "templates",
-                 job_queue=None, env_setup=None):
+    @beartype
+    def __init__(
+            self,
+            job_name: str,
+            cmd: str,
+            prep: str,
+            recipe: str,
+            gen_script_dir: Path,
+            log_dir: Path,
+            partition: str,
+            job_array_size: int,
+            cpus_per_task: int,
+            gpus_per_task: int,
+            refresh_logs: bool,
+            exclude: str,
+            use_custom_ray_tmp_dir: bool,
+            ssh_forward: str,
+            time_limit: str,
+            throttle_array: int,
+            mem: str,
+            constraint_str: str,
+            template_dir: Path = Path(__file__).parent / "templates",
+            job_queue: Optional[str] = None,
+            env_setup: Optional[str] = None,
+    ):
         self.cmd = cmd
         self.mem = mem
         self.prep = prep
@@ -193,7 +214,7 @@ class Yaspi:
             watched_logs.append(str(watched_log.resolve()))
         return watched_logs
 
-    @typechecked
+    @beartype
     def submit(self, watch: bool = True, conserve_resources: int = 5):
         if watch:
             watched_logs = self.get_log_paths()
@@ -236,16 +257,17 @@ class Yaspi:
             summary += f"{key}: {val}\n"
         return summary
 
-    def fill_template(self, template_path, rules):
+    @beartype
+    def fill_template(self, template_path: Path, rules: dict) -> str:
         """Transform a template according to a given set of rules.
 
         Args:
-            template_path (str): location of the template to be filled.
+            template_path: location of the template to be filled.
             rules (dict[str:object]): a key, value mapping between template keys
                 and their target values.
 
         Returns:
-            (str): a single string represnting the transformed contents of the template
+            A single string represnting the transformed contents of the template
                 file.
         """
         generated = []
@@ -275,7 +297,7 @@ class Yaspi:
 
 
 def main():
-    parser = argparse.ArgumentParser(description="yaspi tool")
+    parser = argparse.ArgumentParser(description="Yaspi Tool")
     parser.add_argument("--install_location", action="store_true",
                         help="if given, report the install location of yaspi")
     parser.add_argument("--job_name", default="yaspi-test",
